LeaseControlLocalServerHandler

Trait LeaseControlLocalServerHandler 

pub trait LeaseControlLocalServerHandler<___T = Channel>
where ___T: Transport,
{ // Required method fn watch_status( &mut self, request: Request<WatchStatus, ___T>, responder: Responder<WatchStatus, ___T>, ) -> impl Future<Output = ()>; // Provided method fn on_unknown_interaction( &mut self, ordinal: u64, ) -> impl Future<Output = ()> { ... } }
A server handler for the LeaseControl protocol.

See LeaseControl for more details.

Required Methods

fn watch_status( &mut self, request: Request<WatchStatus, ___T>, responder: Responder<WatchStatus, ___T>, ) -> impl Future<Output = ()>

Get the current status of the lease. If last_status is UNKNOWN, the call will return immediately with the current status. Otherwise, the call will block until the current status differs from last_status.

Provided Methods

fn on_unknown_interaction(&mut self, ordinal: u64) -> impl Future<Output = ()>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<___H, ___T> LeaseControlLocalServerHandler<___T> for Local<___H>
where ___H: LeaseControlServerHandler<___T>, ___T: Transport,

Source

async fn watch_status( &mut self, request: Request<WatchStatus, ___T>, responder: Responder<WatchStatus, ___T>, )

Source

async fn on_unknown_interaction(&mut self, ordinal: u64)

Implementors