ElementInfoProviderLocalServerHandler

Trait ElementInfoProviderLocalServerHandler 

pub trait ElementInfoProviderLocalServerHandler<___T: Transport = Channel> {
    // Required methods
    fn get_element_power_level_names(
        &mut self,
        responder: Responder<GetElementPowerLevelNames, ___T>,
    ) -> impl Future<Output = ()>;
    fn get_status_endpoints(
        &mut self,
        responder: Responder<GetStatusEndpoints, ___T>,
    ) -> impl Future<Output = ()>;

    // Provided method
    fn on_unknown_interaction(
        &mut self,
        ordinal: u64,
    ) -> impl Future<Output = ()> { ... }
}
A server handler for the ElementInfoProvider protocol.

See ElementInfoProvider for more details.

Required Methods

fn get_element_power_level_names( &mut self, responder: Responder<GetElementPowerLevelNames, ___T>, ) -> impl Future<Output = ()>

Returns mappings of PowerLevels to plaintext names for each element managed by a component. Returns an error if no mappings can be returned.

fn get_status_endpoints( &mut self, responder: Responder<GetStatusEndpoints, ___T>, ) -> impl Future<Output = ()>

Returns available Status client endpoints and stable identifiers for each element managed by a component. Returns an error if no endpoints can be returned (i.e. no elements were able to implement the Status channel).

Provided Methods

fn on_unknown_interaction(&mut self, ordinal: u64) -> impl Future<Output = ()>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<___H, ___T> ElementInfoProviderLocalServerHandler<___T> for Local<___H>
where ___H: ElementInfoProviderServerHandler<___T>, ___T: Transport,

Source

async fn get_element_power_level_names( &mut self, responder: Responder<GetElementPowerLevelNames, ___T>, )

Source

async fn get_status_endpoints( &mut self, responder: Responder<GetStatusEndpoints, ___T>, )

Source

async fn on_unknown_interaction(&mut self, ordinal: u64)

Implementors