StatusLocalServerHandler

Trait StatusLocalServerHandler 

pub trait StatusLocalServerHandler<___T: Transport = Channel> {
    // Required method
    fn watch_power_level(
        &mut self,
        responder: Responder<WatchPowerLevel, ___T>,
    ) -> impl Future<Output = ()>;

    // Provided method
    fn on_unknown_interaction(
        &mut self,
        ordinal: u64,
    ) -> impl Future<Output = ()> { ... }
}
A server handler for the Status protocol.

See Status for more details.

Required Methods

fn watch_power_level( &mut self, responder: Responder<WatchPowerLevel, ___T>, ) -> impl Future<Output = ()>

Returns the current power level for this element. The first call on this channel will return immediately. Subsequent calls will block until the current power level has changed.

Provided Methods

fn on_unknown_interaction(&mut self, ordinal: u64) -> impl Future<Output = ()>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<___H, ___T> StatusLocalServerHandler<___T> for Local<___H>
where ___H: StatusServerHandler<___T>, ___T: Transport,

Source

async fn watch_power_level( &mut self, responder: Responder<WatchPowerLevel, ___T>, )

Source

async fn on_unknown_interaction(&mut self, ordinal: u64)

Implementors