#[repr(C)]pub struct LessorLeaseRequest {
pub level: u8,
}Expand description
The wire type corresponding to LessorLeaseRequest.
Fields
level: u8Trait Implementations
Sourceimpl Constrained for LessorLeaseRequest
impl Constrained for LessorLeaseRequest
Sourceimpl Debug for LessorLeaseRequest
impl Debug for LessorLeaseRequest
Sourceimpl<___D> Decode<___D> for LessorLeaseRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for LessorLeaseRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<LessorLeaseRequest, ___E> for LessorLeaseRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<LessorLeaseRequest, ___E> for LessorLeaseRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, LessorLeaseRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, LessorLeaseRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LessorLeaseRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LessorLeaseRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<LessorLeaseRequest, ___E> for LessorLeaseRequest<T0>
impl<___E, T0> Encode<LessorLeaseRequest, ___E> for LessorLeaseRequest<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LessorLeaseRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LessorLeaseRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<LessorLeaseRequest> for LessorLeaseRequest
impl FromWire<LessorLeaseRequest> for LessorLeaseRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<LessorLeaseRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<LessorLeaseRequest, Self>
Sourcefn from_wire(wire: LessorLeaseRequest) -> Self
fn from_wire(wire: LessorLeaseRequest) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for LessorLeaseRequest
impl IntoNatural for LessorLeaseRequest
Sourcetype Natural = LessorLeaseRequest
type Natural = LessorLeaseRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for LessorLeaseRequest
impl Wire for LessorLeaseRequest
Sourcetype Narrowed<'de> = LessorLeaseRequest
type Narrowed<'de> = LessorLeaseRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.