#[repr(C)]pub struct StatusWatchPowerLevelResponse {
pub current_level: u8,
}Expand description
The wire type corresponding to StatusWatchPowerLevelResponse.
Fields
current_level: u8Trait Implementations
Sourceimpl Constrained for StatusWatchPowerLevelResponse
impl Constrained for StatusWatchPowerLevelResponse
Sourceimpl<___D> Decode<___D> for StatusWatchPowerLevelResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for StatusWatchPowerLevelResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<StatusWatchPowerLevelResponse, ___E> for StatusWatchPowerLevelResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<StatusWatchPowerLevelResponse, ___E> for StatusWatchPowerLevelResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, StatusWatchPowerLevelResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, StatusWatchPowerLevelResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StatusWatchPowerLevelResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StatusWatchPowerLevelResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<StatusWatchPowerLevelResponse, ___E> for StatusWatchPowerLevelResponse<T0>
impl<___E, T0> Encode<StatusWatchPowerLevelResponse, ___E> for StatusWatchPowerLevelResponse<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StatusWatchPowerLevelResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StatusWatchPowerLevelResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<StatusWatchPowerLevelResponse> for StatusWatchPowerLevelResponse
impl FromWire<StatusWatchPowerLevelResponse> for StatusWatchPowerLevelResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StatusWatchPowerLevelResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<StatusWatchPowerLevelResponse, Self>
Sourcefn from_wire(wire: StatusWatchPowerLevelResponse) -> Self
fn from_wire(wire: StatusWatchPowerLevelResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for StatusWatchPowerLevelResponse
impl IntoNatural for StatusWatchPowerLevelResponse
Sourcetype Natural = StatusWatchPowerLevelResponse
type Natural = StatusWatchPowerLevelResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for StatusWatchPowerLevelResponse
impl Wire for StatusWatchPowerLevelResponse
Sourcetype Narrowed<'de> = StatusWatchPowerLevelResponse
type Narrowed<'de> = StatusWatchPowerLevelResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.